@@ -28,6 +28,7 @@ test_format <- function(name, os_skip = NULL) {
 test_format("acm_article")
 test_format("acs_article")
 test_format("aea_article")
+test_format("agu_article")
 test_format("ams_article")
 test_format("asa_article")
 test_format("biometrics_article")
@@ -40,7 +41,9 @@ test_format("rjournal_article")
 test_format("sage_article")
 test_format("sim_article")
 test_format("peerj_article")
+test_format("plos_article")
 test_format("amq_article")
 test_format("mdpi_article")
 test_format("mnras_article")
 test_format("copernicus_article")
+test_format("frontiers_article")
